pub enum SftpFuture<Output = (), State = ()> {
Error(Error),
Pending {
future: Receiver<Result<Message, Error>>,
state: State,
f: fn(State, Message) -> Result<Output, Error>,
},
Polled,
}Expand description
SFTP future.
Represents a future of a SFTP request that returns a Result<Output, Error> when polled.
If the request had an error even before being sent, the error will be returned when polled.
If State is 'static, then the future itself is also 'static.
Cancel safety
It is safe to cancel the future. However, the request is actually sent before the future is created.
Variants
Error(Error)
An error occured before sending the request to the SFTP server.
Pending
Waiting the result from the SFTP server.
Fields

state: StatePolled
The future has already been polled.