Init

Struct Init 

pub struct Init {
    pub version: u32,
    pub extensions: BTreeMap<Bytes, Bytes>,
}
Initialization packet.

It is answered with Version.

internal: SSH_FXP_INIT

Fields

version: u32

Maximal version of the protocol supported by the client

extensions: BTreeMap<Bytes, Bytes>

List of extensions supported by the client

Implementations MUST silently ignore any extensions whose name they do not recognize.