pub struct Attrs {
pub size: Option<u64>,
pub owner: Option<Owner>,
pub perms: Option<Permisions>,
pub time: Option<Time>,
}Expand description
Attributes of a file or a directory.
The same encoding is used both when returning file attributes from the server and when sending file attributes to the server. When sending it to the server, the flags field specifies which attributes are included, and the server will use default values for the remaining attributes (or will not modify the values of remaining attributes). When receiving attributes from the server, the flags specify which attributes are included in the returned data. The server normally returns all attributes it knows about.
internal: SSH_FXP_ATTRS
Fields
size: Option<u64>Size of the file (optional)
owner: Option<Owner>Owner of the file (optional)
perms: Option<Permisions>Permissions of the file (optional)
time: Option<Time>Access and Modification time of the file (optional)
Implementations