pub struct Init {
pub version: u32,
pub extensions: BTreeMap<Bytes, Bytes>,
}Expand description
Fields
version: u32Maximal version of the protocol supported by the client
extensions: BTreeMap<Bytes, Bytes>List of extensions supported by the client
Implementations MUST silently ignore any extensions whose name they do not recognize.