pub struct SetStat {
pub path: Path,
pub attrs: Attrs,
}Expand description
Request to change the attributes (metadata) of a file or directory.
This request is used for operations such as changing the ownership, permissions or access times, as well as for truncating a file.
An error will be returned if the specified file system object does not exist or the user does not have sufficient rights to modify the specified attributes.
It is answered with Status.
internal: SSH_FXP_SETSTAT
Fields
path: PathPath of the file or directory to change the attributes
attrs: AttrsNew attributes to apply